# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Test-Deep
Version:	1.205
Release:	1.%{__distinit}%{__distvers}
Summary:	Extremely flexible deep comparison
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Deep
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Deep-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(:VERSION) >= 5.12
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.78
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(overload)
BuildRequires:	perl(Scalar::Util) >= 1.09
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(if)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::More) >= 0.96
BuildRequires:	perl(Test::Tester) >= 0.107
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Test::Builder)

%description
Test::Deep gives you very flexible ways to check that the result you
got is the result you were expecting. At its simplest it compares two
structures by going through each level, ensuring that the values
match, that arrays and hashes have the same elements and that
references are blessed into the correct class. It also handles
circular data structures without getting caught in an infinite loop.

%prep
%setup -q -n Test-Deep-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor NO_PACKLIST=1 NO_PERLLOCAL=1
%{make_build}

%install
%{make_install}
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README TODO
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Deep.3*
%{_mandir}/man3/Test::Deep::*.3*

%changelog
* Tue Apr  1 2025 Paul Howarth <paul@city-fan.org> - 1.205-1
- Update to 1.205
  - Add "use v5.12" to Test::Deep, just for clarity
  - Fix a test so that if an "A" module is in @INC, the tests still pass
- Use %%{make_build} and %%{make_install}
- Drop support for building with ExtUtils::MakeMaker < 6.78

* Fri Jul 14 2023 Paul Howarth <paul@city-fan.org> - 1.204-2
- Avoid use of deprecated patch syntax

* Sun Jan  8 2023 Paul Howarth <paul@city-fan.org> - 1.204-1
- Update to 1.204
  - Try to avoid clobbering global error variables when loading test libraries
  - hash_each now enumerates keys in sort() order, to make errors more consistent

* Thu Jan  5 2023 Paul Howarth <paul@city-fan.org> - 1.202-1
- Update to 1.202
  - Converted to Dist::Zilla
  - Test::Deep will now require v5.12, and this may go up; this change allows
    simplification of the Makefile.PL, which was coping with a mistake made
    twelve years ago
- Use SPDX-format license tag
- Package LICENSE file
- Add patch to support building with ExtUtils::MakeMaker < 6.78

* Mon Mar  2 2020 Paul Howarth <paul@city-fan.org> - 1.130-1
- Update to 1.128
  - Allow 'use Test::Deep' while other modules use Test::Deep::NoTest (GH#76)
  - Added true/false optional imports (GH#41, GH#44)
  - Documentation fixes (GH#79)

* Fri Apr 20 2018 Paul Howarth <paul@city-fan.org> - 1.128-1
- Update to 1.128
  - Numerous small improvements to documentation
  - Improved CI setup

* Tue Apr 10 2018 Paul Howarth <paul@city-fan.org> - 1.127-4
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Thu May  4 2017 Paul Howarth <paul@city-fan.org> - 1.127-1
- Update to 1.127
  - Do not eagerly convert simple scalars into tests in the all, any and none
    tests; this was breaking LeafWrapper application
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88

* Sun Jan  1 2017 Paul Howarth <paul@city-fan.org> - 1.126-1
- Update to 1.126
  - If objects in the "expected" structure have an as_test_deep_cmp method, it
    will be called and its return (which should be a Test::Deep::Cmp object)
    will be used as the test for that location in the structure
  - Internal undocumented class_base routine has been replaced with a
    different, clearly private routine
  - The LeafWrapper is also used for objects with an unknown reftype (like
    LVALUE or other weird ones)
- Update patch to support building with Test::More < 0.88

* Sun Nov  6 2016 Paul Howarth <paul@city-fan.org> - 1.124-1
- Update to 1.124
  - Avoid an uninitialized warning when array_each() compares to a
    non-reference

* Sat Sep 10 2016 Paul Howarth <paul@city-fan.org> - 1.123-1
- Update to 1.123
  - Remove test suite reliance on "." appearing @INC
  - When an object with stringification overloading fails to match a "re" test,
    its stringification is included in the diagnostics
- Update patch to support building with Test::More < 0.88

* Thu Sep  8 2016 Paul Howarth <paul@city-fan.org> - 1.122-1
- Update to 1.122
  - Added $Test::Deep::LeafWrapper to control the behavior of simple values in
    the "expected" definition
  - Documentation improvements
  - Avoid a few evals, localize $@ in a few places where eval is used
  - Goodbye tabs, hello spaces
- BR: perl-generators where available
- Simplify find command using -delete
- Update patch to support building with Test::More < 0.88

* Mon Nov 30 2015 Paul Howarth <paul@city-fan.org> - 1.120-1
- Update to 1.120
  - Add none() test; it's like any(), but negative
  - Fix stringification of any() expectations

* Wed Sep 30 2015 Paul Howarth <paul@city-fan.org> - 0.119-1
- Update to 0.119
  - Overloading of & and | no longer can change All or Any objects found as
    arguments
  - An All as an argument to an All constructed is flattened out into its
    All-ed values; the same goes for Any
  - Remove use of Test::NoWarnings for user-facing tests
- Add patch to support building with Test::More < 0.88

* Mon Jun 22 2015 Paul Howarth <paul@city-fan.org> - 0.117-1
- Update to 0.117
  - Do not lose argument(s) to import
    (https://github.com/rjbs/Test-Deep/issues/29)

* Sun Jun 21 2015 Paul Howarth <paul@city-fan.org> - 0.116-1
- Update to 0.116
  - On its own, :preload options uses default group of exports

* Sat Jan 10 2015 Paul Howarth <paul@city-fan.org> - 0.115-1
- Update to 0.115
  - Worked around a bug in chained goto on 5.8.5

* Mon Dec 15 2014 Paul Howarth <paul@city-fan.org> - 0.114-1
- Update to 0.114
  - Improve prereqs metadata
  - Add a noneof() set test
  - regexponly hasn't worked... ever; now it does
  - Passing :preload to import loads all plugins up front
  - A few more tests have been documented
  - The many exports of Test::Deep are now documented!

* Thu Nov 13 2014 Paul Howarth <paul@city-fan.org> - 0.113-1
- Update to 0.113
  - Fix a compile error (!!) in RegexpOnly
  - Fix some documentation typos
  - Add license to META file
- Classify buildreqs by usage

* Tue Sep  2 2014 Paul Howarth <paul@city-fan.org> - 0.112-3
- Drop %%defattr, redundant since rpm 4.4

* Sat Nov 30 2013 Paul Howarth <paul@city-fan.org> - 0.112-1
- Update to 0.112:
  - When printing diagnostics, differentiate the type of a blessed object from
    the name of the class itself (CPAN RT#78288)
  - Typo fixes
  - Fixes to clarity and accuracy of documentation
  - Add metadata links to repo and issue tracker
  - Added obj_isa for testing ->isa without falling back to ref($x)
  - Added the *experimental* ":v1" export group to skip importing Isa, isa, and
    blessed

* Sun Jun 17 2012 Paul Howarth <paul@city-fan.org> - 0.110-1
- Update to 0.110:
  - Allow methods() and listmethods() to work again on class methods
    (CPAN RT#77804)
- Drop arrayeach patch - similar change introduced upstream
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Drop workaround for test issues with 5.8.0 (CPAN RT#27630)

* Fri Feb 17 2012 Paul Howarth <paul@city-fan.org> - 0.109-1
- Update to 0.109:
  - UNIVERSAL::isa and UNIVERAL::can are no longer called as functions: this
    was deprecated in UNIVERSAL 1.03 (CPAN RT#74760)
  - The code that builds the exporter configuration is cleaned up; more
    documentation of how it may change (for the better, without breaking stuff)
    should appear in the near future
- Add buildreqs for Perl core modules that might be dual-lived

* Tue Jun 28 2011 Paul Howarth <paul@city-fan.org> - 0.108-4
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> - 0.108-2
- Skip bag.t, circular.t, and set.t on 5.8.0 (Perl RT#27630)
- Nobody else likes macros for commands
- Use %%{_fixperms} macro instead of our own chmod incantation

* Sun Oct 17 2010 Paul Howarth <paul@city-fan.org> - 0.108-1
- Update to 0.108:
  - Simple (stringwise) comparison should now be much faster

* Thu Sep 30 2010 Paul Howarth <paul@city-fan.org> - 0.107-1
- Update to 0.107:
  - New maintainer: Ricardo Signes (rjbs)
  - Install by default to "site" directory on perl ≥ 5.10.0
  - Cope with new stringification of qr{} objects in 5.13.x+
  - Fix Pod escaping errors
- This release by RJBS -> update source URL

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.106-4
- Rebuild for perl 5.12.1 in Rawhide

* Wed May 12 2010 Paul Howarth <paul@city-fan.org> - 0.106-3
- Fix dist tag for RHEL-6 Beta

* Thu Nov 26 2009 Paul Howarth <paul@city-fan.org> - 0.106-2
- Import from Fedora

* Fri Oct 30 2009 Stepan Kasal <skasal@redhat.com> - 0.106-1
- New upstream version

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.103-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.103-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Oct 22 2008 Lubomir Rintel <lubo.rintel@gooddata.com> - 0.103-2
- Fix crash on matching array_each() against non-array

* Wed Jun 04 2008 Steven Pritchard <steve@kspei.com> - 0.103-1
- Update to 0.103

* Sat May 31 2008 Steven Pritchard <steve@kspei.com> - 0.102-1
- Update to 0.102

* Fri May 16 2008 Steven Pritchard <steve@kspei.com> - 0.101-1
- Update to 0.101

* Sat Feb  2 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.100-2
- Rebuild for new perl

* Mon Jan 28 2008 Steven Pritchard <steve@kspei.com> - 0.100-1
- Update to 0.100

* Sat Jan 12 2008 Steven Pritchard <steve@kspei.com> - 0.099-1
- Update to 0.099
- Update License tag

* Tue Sep 18 2007 Steven Pritchard <steve@kspei.com> - 0.098-1
- Update to 0.098

* Fri Aug 10 2007 Steven Pritchard <steve@kspei.com> - 0.097-1
- Update to 0.097

* Wed Apr 18 2007 Steven Pritchard <steve@kspei.com> - 0.096-2
- Use fixperms macro instead of our own chmod incantation
- BR ExtUtils::MakeMaker

* Tue Sep 26 2006 Steven Pritchard <steve@kspei.com> - 0.096-1
- Update to 0.096

* Sat Sep 16 2006 Steven Pritchard <steve@kspei.com> - 0.095-2
- Fix find option order

* Fri Apr 21 2006 Steven Pritchard <steve@kspei.com> - 0.095-1
- Update to 0.095

* Sat Apr 08 2006 Steven Pritchard <steve@kspei.com> - 0.093-1
- Specfile autogenerated by cpanspec 1.64
- Improve description
- Fix License
- Remove explicit dependency on Test::Tester and Test::NoWarnings
